@@ -78,6 +78,7 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
             except:
                 won_perc = 0
                 print('No winning trades')
+
         ### LONG
         try:
             LongTotal = s.analyzers.TradeAnalyzer.rets.long.total
@@ -171,10 +172,12 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         except:
             pass
 
+        if TotalTrades== 0:
+            won_perc = np.nan
         try:
             if won_perc == 1:
-                profitfactor = np.nan
-            elif won_perc == 0:
+                profitfactor = np.inf
+            elif won_perc == 0 or won_perc == np.nan:
                 profitfactor = np.nan
             else:
                 profitfactor = round(
@@ -186,11 +189,13 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         ##  -----------------      LONG
 
         won_long_perc = round(DirX.DivByZero_int(LongWon, LongTotal),3)
+        if LongTotal == 0:
+            won_long_perc = np.nan
         # won_long_perc = "{:.2%}".format(won_long_perc)
 
         if won_long_perc == 1:
-            profitfactorlong = np.nan
-        elif won_long_perc == 0:
+            profitfactorlong = np.inf
+        elif won_long_perc == 0 or won_long_perc == np.nan:
             profitfactorlong = np.nan
         else:
             profitfactorlong = round(DirX.DivByZero_int(-LongPnlWon,LongPnlLost),3)
@@ -198,12 +203,14 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         ##  -----------------      SHORT
 
         won_short_perc = round(DirX.DivByZero_int(ShortWon,ShortTotal),3)
+        if ShortTotal == 0:
+            won_short_perc = np.nan
         # won_short_perc = "{:.2%}".format(won_short_perc)
 
 
         if won_short_perc == 1:
-            profitfactorshort = np.nan
-        elif won_short_perc == 0:
+            profitfactorshort = np.inf
+        elif won_short_perc == 0 or won_short_perc == np.nan:
             profitfactorshort = np.nan
         else:
             profitfactorshort = round(DirX.DivByZero_int(-ShortPnlWon,ShortPnlLost),
@@ -214,14 +221,20 @@ def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
         avg_pnl = round(DirX.DivByZero_int(totalnet_pnl, TotalTrades), 3)
 
 
-        PNL_MDWD = round(DirX.DivByZero_int(totalnet_pnl, MinValue), 3)
-        if abs(totalnet_pnl) <= abs(MinValue) and totalnet_pnl > 0:
-            PNL_MDWD = -PNL_MDWD
+        PNL_MDWD = round(DirX.DivByZero_int(-totalnet_pnl, MinValue), 3)
+        if totalnet_pnl > 0 and MinValue == 0:
+            PNL_MDWD = np.inf
+        elif PNL_MDWD == 0:
+            PNL_MDWD = np.nan
 
 
         EXTFACT = round(DirX.DivByZero_int(MaxValue, MinValue), 3)
         if EXTFACT <= -1:
             EXTFACT = -EXTFACT
+        elif MaxValue > 0 and MinValue == 0:
+            EXTFACT = np.inf
+        elif MaxValue == 0 and MinValue < 0:
+            EXTFACT = -np.inf
 
 
         Analysislist = ([totalnet_pnl, won_perc, profitfactor,
